@@ -230,6 +230,7 @@ sub new {
     my ( $attribute, $block, $object, @results, $value );
 
     for my $line (@lines) {
+        next if !defined($line);
 
         if ( $line =~ /^%(\S+)/ ) {
 
@@ -239,7 +240,7 @@ sub new {
             $attribute = 'response';
             $value     = $1;
 
-        } elsif ( $line =~ /^(\S+):\s+(.*)/ ) {
+        } elsif ( $line =~ /^(\S+):\s*(.*)/ ) {
 
             # Attribute line
             $attribute = $1;
@@ -680,10 +681,6 @@ sub _object_factory {
             $rir = $a->[1];
             $rir =~ s/^(\S+)\s*#.*/$1/;
             $rir = uc $rir;
-            # RADB use same database as RIPE
-            if ($rir eq 'RADB') {
-                    $rir = 'RIPE';
-            }   
             $rir = undef if $rir =~ /^(RIPE|TEST)$/;    # For historical/compatibility reason RIPE objects aren't derived
         }
     }
